# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_154_AllFetches(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_154)

  def run_test_154(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    server = DbtPy.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'Inf'):
      op = {DbtPy.ATTR_CASE: DbtPy.CASE_UPPER}
      DbtPy.set_option(conn, op, 1)

    try:
        statement = 'DROP TABLE fetch_test'
        result = DbtPy.exec_immediate(conn, statement)
    except:
        pass
    
    server = DbtPy.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'Inf'):
      statement = 'CREATE TABLE fetch_test (col1 VARCHAR(20), col2 CLOB, col3 INTEGER)'
      st0 = "INSERT INTO fetch_test VALUES ('column 0', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\data1.txt','client'), 0)"
      st1 = "INSERT INTO fetch_test VALUES ('column 1', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\data2.txt','client'), 1)"
      st2 = "INSERT INTO fetch_test VALUES ('column 2', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\data3.txt','client'), 2)"
      st3 = "INSERT INTO fetch_test VALUES ('column 3', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\data4.txt','client'), 3)"
    else:
      statement = 'CREATE TABLE fetch_test (col1 VARCHAR(20), col2 CLOB(20), col3 INTEGER)'
      st0 = "INSERT INTO fetch_test VALUES ('column 0', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\data1.txt','client'), 0)"
      st1 = "INSERT INTO fetch_test VALUES ('column 1', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\data2.txt','client'), 1)"
      st2 = "INSERT INTO fetch_test VALUES ('column 2', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\data3.txt','client'), 2)"
      st3 = "INSERT INTO fetch_test VALUES ('column 3', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\data4.txt','client'), 3)"
    result = DbtPy.exec_immediate(conn, statement)

    result = DbtPy.exec_immediate(conn, st0)
    result = DbtPy.exec_immediate(conn, st1)
    result = DbtPy.exec_immediate(conn, st2)
    result = DbtPy.exec_immediate(conn, st3)

    statement = "SELECT col1, col2 FROM fetch_test"
    result = DbtPy.prepare(conn, statement)
    DbtPy.execute(result)

    row = DbtPy.fetch_tuple(result)
    while ( row ):
      #printf("\"%s\" from VARCHAR is %d bytes long, \"%s\" from CLOB is %d bytes long.\n",
      #        row[0],row[0].length, row[1],row[1].length)
      print("\"%s\" from VARCHAR is %d bytes long, \"%s\" from CLOB is %d bytes long." %\
        (row[0], len(row[0]), row[1], len(row[1])))
      row = DbtPy.fetch_tuple(result)

    result = DbtPy.prepare(conn, statement)
    DbtPy.execute(result)

    row = DbtPy.fetch_assoc(result)
    while ( row ):
      #printf("\"%s\" from VARCHAR is %d bytes long, \"%s\" from CLOB is %d bytes long.\n",
      #        row['COL1'], row['COL1'].length, row['COL2'], row['COL2'].length)
      print("\"%s\" from VARCHAR is %d bytes long, \"%s\" from CLOB is %d bytes long." %\
        (row['COL1'], len(row['COL1']), row['COL2'], len(row['COL2'])))
      row = DbtPy.fetch_assoc(result)
      
    result = DbtPy.prepare(conn, statement)
    DbtPy.execute(result)

    row = DbtPy.fetch_both(result)
    while ( row ):
      #printf("\"%s\" from VARCHAR is %d bytes long, \"%s\" from CLOB is %d bytes long.\n",
      #        row['COL1'], row['COL1'].length, row[1], row[1].length)
      print("\"%s\" from VARCHAR is %d bytes long, \"%s\" from CLOB is %d bytes long.\n" % \
        (row['COL1'],len(row['COL1']), row[1], len(row[1])))
      row = DbtPy.fetch_both(result)

    DbtPy.close(conn)

#__END__
#__LUW_EXPECTED__
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#__ZOS_EXPECTED__
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#__SYSTEMI_EXPECTED__
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#__IDS_EXPECTED__
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.
#"column 0" from VARCHAR is 8 bytes long, "Data in the clob 0" from CLOB is 18 bytes long.
#"column 1" from VARCHAR is 8 bytes long, "Data in the clob 1" from CLOB is 18 bytes long.
#"column 2" from VARCHAR is 8 bytes long, "Data in the clob 2" from CLOB is 18 bytes long.
#"column 3" from VARCHAR is 8 bytes long, "Data in the clob 3" from CLOB is 18 bytes long.



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_115_NumericTest_02(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_115)

  def run_test_115(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    server = DbtPy.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'Inf'):
      op = {DbtPy.ATTR_CASE: DbtPy.CASE_UPPER}
      DbtPy.set_option(conn, op, 1)
    
    if conn:
      drop = "drop table numericliteral"
      try:
        DbtPy.exec_immediate( conn, drop )
      except:
        pass

      create = "create table numericliteral ( id INTEGER, data VARCHAR(50) )"
      DbtPy.exec_immediate(conn, create)

      insert = "INSERT INTO numericliteral (id, data) values (12, 'NUMERIC LITERAL TEST')"
      DbtPy.exec_immediate(conn, insert)

      stmt = DbtPy.prepare(conn, "SELECT data FROM numericliteral")
      DbtPy.execute(stmt)
      
#      NOTE: This is a workaround
#      function fetch_object() to be implemented...
#      row = DbtPy.fetch_object(stmt, 0)
      
      class Row:
          pass
      
      row = Row()
      DbtPy.fetch_row(stmt, 0)
      if (server.DBMS_NAME[0:3] != 'Inf'):
        row.DATA = DbtPy.result(stmt, 'DATA')
      else:
        row.DATA = DbtPy.result(stmt, 'data')
      print(row.DATA)

      insert = "UPDATE numericliteral SET data = '@@@@@@@@@@' WHERE id = '12'"
      DbtPy.exec_immediate(conn, insert)

      stmt = DbtPy.prepare(conn, "SELECT data FROM numericliteral")
      DbtPy.execute(stmt)
      
#      row = DbtPy.fetch_object(stmt, 0)
      DbtPy.fetch_row(stmt, 0)
      if (server.DBMS_NAME[0:3] != 'Inf'):
        row.DATA = DbtPy.result(stmt, 'DATA')
      else:
        row.DATA = DbtPy.result(stmt, 'data')
      print(row.DATA)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__ZOS_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__SYSTEMI_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__IDS_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@



#

#

#

import unittest, sys, os
import DbtPy
#need to add this line below to each file to make the connect parameters available to all the test files
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_313_Collection(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_313)

  def run_test_313(self):
    # Make a connection
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    # Get the server type
    server = DbtPy.server_info( conn )

    try:
        sql = "drop table collection_tab;"
        stmt = DbtPy.exec_immediate(conn, sql)
    except:
         pass
  
    SetupSqlSet = [
        "create table collection_tab ( col1 int, s1 SET(float not null), m1  MULTISET(char(20) not null), l1 LIST(bigint not null)) ;",
        "insert into collection_tab values( 1, SET{11.10, 12.11},  MULTISET{'Hey', 'Hell'}, LIST{120, -120});",
        "insert into collection_tab values( 2, SET{13.11, 14.20},  MULTISET{'Jhon', 'Nick'}, LIST{130, -130});",
        "insert into collection_tab values( 3, SET{14.21, 14.00},  MULTISET{'Dave', 'Mill'}, LIST{140, -141});",
        "insert into collection_tab values( 4, SET{15.0, 16},      MULTISET{'Mon', 'Phebee'}, LIST{150, -150});"
    ]

    i = 0
    for sql in SetupSqlSet:
        i += 1
        stmt = DbtPy.exec_immediate(conn, sql)

    sql = "select * from collection_tab;"
    stmt =  DbtPy.exec_immediate(conn, sql)
    tu = DbtPy.fetch_tuple(stmt)
    rc = 0
    while tu != False:
        rc += 1
        tu = DbtPy.fetch_tuple(stmt)

    print ("Collection Data Access complete")

#__END__
#__LUW_EXPECTED__
#Collection Data Access complete
#__ZOS_EXPECTED__
#Collection Data Access complete
#__SYSTEMI_EXPECTED__
#Collection Data Access complete
#__IDS_EXPECTED__
#Collection Data Access complete





import os
import sys
import struct
from setuptools import setup, find_packages
from distutils.core import Extension
import tarfile
import zipfile
import shutil
import glob
import platform

if sys.version_info >= (3, ):
    from urllib import request
    from io import BytesIO
else:
    import urllib2 as request
    from cStringIO import StringIO as BytesIO

from distutils.sysconfig import get_python_lib
from setuptools.command.build_ext import build_ext
from setuptools.command.install import install

this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_desc = f.read()

# Writing the Setup Script
# https://docs.python.org/3.4/distutils/setupscript.html#distutils-installing-scripts


PACKAGE   = 'DbtPy'
VERSION   = '3.0.5.2'
VERSION2X = '2.7.1'
LICENSE   = 'Apache License 2.0'
DbtPyLongDescription='GBase 8s native Python driver is a high performing data access interface suitable for highly scalable enterprise with GBase 8s database.'

# Python 3.4 and up and not commit to Python 4 support yet
PYTHON_REQ = '~=3.4'

PYTHON_REQ_2X = '>=2.7, <3'


# Specifying the files to distribute
# https://docs.python.org/3.4/distutils/sourcedist.html#manifest
# DbtPy_modules = ['config', 'DbtPyDbi', 'testfunctions', 'tests']
DbtPy_modules = ['DbtPyDbi']


#package_data = { 'DbtPyPkg': [ 'data/DbtPyPackageData1.txt', 'data/DbtPyPackageData2.txt']}
# package_data = { 'DbtPyPkgData': [ 'data/*.txt'] }

# Installing Additional Files
# https://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files
# data_files = [ ('DbtPySample', ['./README.rst']),
#                ('DbtPySample', ['../Examples/Sample1.py']),
#                ('DbtPySample', ['../Examples/DbAPI_Sample1.py']),
#                ('DbtPySample', ['../Examples/DbAPI_Sample_executemany.py']),
#                ('DbtPySample', ['../Examples/DbAPI_Sample_Params.py']),
#                ('DbtPySample', ['./LICENSE.txt']) ]

machine_bits =  8 * struct.calcsize("P")
is64Bit = False
prefix = ''

if machine_bits == 64:
    is64Bit = True
    sys.stdout.write("Detected 64-bit Python\n")
else:
    sys.stdout.write("Detected 32-bit Python\n")
	
if('win32' in sys.platform):
	os_ = 'win'
	cliFileName = 'GBase8s_3.0-Win64-ODBC-Driver.zip'
	prefix = 'build/lib.win-amd64-' + str(sys.version_info[0])+"."+str(sys.version_info[1]) + '/'
elif ('linux' in sys.platform):
	os_ = 'linux'
	cliFileName = 'GBase8s_3.0-Linux64-ODBC-Driver.tar.gz'
	prefix = 'build/lib.linux-'+ platform.processor() + '-' + str(sys.version_info[0])+"."+str(sys.version_info[1]) + '/'
else:
	cliFileName = 'Unknown'

gbasedbtdir = os.getenv('GBASEDBTDIR', '')
csdk_home = os.getenv('CSDK_HOME', '')

# Only 64-bit Automated ODBC install is supported, prior installation of CSDK continues to be required for 32-bit 
if is64Bit == True and not gbasedbtdir and not csdk_home:
	tmp_path = os.getcwd()
	pip_odbc_path = os.path.join(tmp_path, 'gbase8s-odbc-driver')
	cpath=''
	cpath1=''

	if not os.path.isdir(pip_odbc_path):
		#url = 'http://127.0.0.1:8000/' + cliFileName
		url = 'https://gbasedbt.com/odbc/' + cliFileName
		sys.stdout.write("Downloading : %s , it will take a few minutes.\n" % (url))
		sys.stdout.flush();

		pip_odbc_path = os.path.join(tmp_path, prefix + 'gbase8s-odbc-driver')
		cpath1 = os.getcwd()
		src = os.path.join(cpath1, prefix + 'gbase8s-odbc-driver')
		
		file_stream = BytesIO(request.urlopen(url).read())
		if (os_ == 'win'):
			sys.stdout.write("Extracting Windows ODBC files : %s\n" % (url))
			cliDriver_zip = zipfile.ZipFile(file_stream)
			cliDriver_zip.extractall(prefix)
		else:
			sys.stdout.write("Extracting Linux ODBC files : %s\n" % (url))
			cliDriver_tar = tarfile.open(fileobj=file_stream)
			cliDriver_tar.extractall(prefix)
	else:
		cpath = os.getcwd()
		pip_odbc_path = os.path.join(cpath, prefix + 'gbase8s-odbc-driver')
		if not os.path.isdir(pip_odbc_path):
			#url = 'http://127.0.0.1:8000/' + cliFileName
			url = 'https://gbasedbt.com/odbc/' + cliFileName
			sys.stdout.write("Downloading : %s , it will take a few minutes.\n" % (url))
			sys.stdout.flush();

			file_stream = BytesIO(request.urlopen(url).read())
			if (os_ == 'win'):
				sys.stdout.write("Extracting Windows ODBC files : %s\n" % (url))
				cliDriver_zip = zipfile.ZipFile(file_stream)
				cliDriver_zip.extractall(prefix)
				#cliDriver_zip.extractall()
			else:
				sys.stdout.write("Extracting Linux ODBC files : %s\n" % (url))
				cliDriver_tar = tarfile.open(fileobj=file_stream)
				cliDriver_tar.extractall(prefix)
				#cliDriver_tar.extractall()
	
if not gbasedbtdir:
	cpath = os.getcwd()
	pip_odbc_path = os.path.join(cpath, prefix + 'gbase8s-odbc-driver')
	if not os.path.isdir(pip_odbc_path):
		raise ValueError("GBASEDBTDIR environment variable must be set!)")
	else:
		gbasedbtdir = pip_odbc_path
		
if not csdk_home:
	cpath = os.getcwd()
	pip_odbc_path = os.path.join(cpath, prefix + 'gbase8s-odbc-driver')
	if not os.path.isdir(pip_odbc_path):
		raise ValueError("CSDK_HOME environment variable must be set!)")
	else:
		csdk_home = pip_odbc_path
		
py_home = os.getenv('MY_PY_DIR', '')
if not py_home:
	cpath = os.getcwd()
	if not os.path.isdir(cpath):
		raise ValueError("MY_PY_DIR environment variable must be set!)")
	else:
		py_home = cpath
		
# Detect CSDK version
# Smart triggers are available from CSDK 4.50
vers_csdk_file = os.path.join(gbasedbtdir, 'etc', '.lvers_csdk')
csdk_version = None
if os.path.exists(vers_csdk_file):
    with open(vers_csdk_file, 'r') as file:
        csdk_version = file.read().strip().split('.')
else:
    sys.stdout.write("Warning: Could not detect CDSK version.\n")

definitions = []
#CSDK/ODBC supports Smart Trigger. 
if csdk_version and ( (int(csdk_version[0]) >= 4 and int(csdk_version[1]) >= 50) ):
    definitions = [('HAVE_SMARTTRIGGER', None)]
    sys.stdout.write("Smart Triggers are enabled.\n")
else:
    sys.stdout.write("Smart Triggers are not available.\n")

if('win32' in sys.platform):
    DbtPyNative_ext_modules = Extension('DbtPy',
        include_dirs = [py_home + '\\include', csdk_home + '\\incl\\cli'],
        libraries = ['iclit09b'],
        define_macros=definitions,
        library_dirs = [ py_home + '\libs', csdk_home + '\lib'],
        sources = ['dbtpyc.c'])
else:
    DbtPyNative_ext_modules = Extension('DbtPy',
        include_dirs = [ py_home,  py_home + '/Include', csdk_home +'/incl/cli'],
        libraries = ['ifdmr', 'thcli'],
        define_macros=definitions,
        library_dirs = [ csdk_home + '/lib/cli', py_home + '/Lib'],
        sources = ['dbtpyc.c'])


# Supporting both Python 2 and Python 3 with Setuptools
# http://setuptools.readthedocs.io/en/latest/python3.html
extra = {}
if sys.version_info >= (3, ):
    extra['use_2to3'] = True
else:
    VERSION    = VERSION2X
    PYTHON_REQ = PYTHON_REQ_2X

setup (name    = PACKAGE,
       version = VERSION,
       license = LICENSE,
       description      = 'GBase 8s native Python driver',
       # long_description = DbtPyLongDescription,
       long_description = long_desc,
       long_description_content_type = 'text/markdown',

       # The project's main homepage.
       url = 'https://gbasedbt.com/DbtPy',
       # project_urls={
       #    'Documentation': 'https://gbasedbt.com/DbtPy/wiki/',
       #    'Source': 'https://gbasedbt.com/DbtPy/',
       #    'Tracker': 'https://gbasedbt.com/DbtPy/',
       #},
       python_requires = PYTHON_REQ,

       author          = 'Informix Application Development Team & GBase 8s Support Team',
       #author_email    = 'dbt@gbasedbt.com',

       # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
       classifiers=[
           # How mature is this project? Common values are
           #   3 - Alpha
           #   4 - Beta
           #   5 - Production/Stable
           'Development Status :: 5 - Production/Stable',

           # Indicate who your project is intended for
           'Intended Audience :: Developers',
           'Topic :: Software Development',

           # Pick your license as you wish (should match "license" above)
           'License :: OSI Approved :: Apache Software License',

           # Specify the Python versions you support here. In particular, ensure
           # that you indicate whether you support Python 2, Python 3 or both.
           'Programming Language :: Python :: 2.7',
           'Programming Language :: Python :: 3.4',
           'Programming Language :: Python :: 3.5',
           'Programming Language :: Python :: 3.6',
           'Programming Language :: Python :: 3.7',
           'Operating System :: Microsoft :: Windows',
           'Operating System :: POSIX',
           'Programming Language :: Python :: Implementation :: CPython',
       ],

       # What does your project relate to?
       keywords='GBase 8s Python Enterprise',

       ext_modules = [DbtPyNative_ext_modules],
       py_modules   = DbtPy_modules,
    #    package_data = package_data,
    #    data_files   = data_files,
    #    include_package_data = True,
       **extra
      ) 




# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_141_BindParamSelectStmtMultipleParams_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_141)

  def run_test_141(self):
    sql = "SELECT id, breed, name, weight FROM animals WHERE id < ? AND weight > ?"
    
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      stmt = DbtPy.prepare(conn, sql)
    
      animal = 5
      mass = 2.0
      DbtPy.bind_param(stmt, 1, animal)
      DbtPy.bind_param(stmt, 2, mass)
    
      if DbtPy.execute(stmt):
        row = DbtPy.fetch_tuple(stmt)
        while ( row ): 
          #row.each { |child| print child }
          for i in row:
            print(i)
          row = DbtPy.fetch_tuple(stmt)
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#2
#horse
#Smarty          
#350.00
#__ZOS_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#2
#horse
#Smarty          
#350.00
#__SYSTEMI_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#2
#horse
#Smarty          
#350.00
#__IDS_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#2
#horse
#Smarty          
#350.00



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_065_FilterTableName(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_065)

  def run_test_065(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )

    create = 'CREATE SCHEMA AUTHORIZATION t'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t1( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t2( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
      
    create = 'CREATE TABLE t.t3( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t4( c1 integer, c2 varchar(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    result = DbtPy.tables(conn, None, '%', "t3")
    columns = DbtPy.num_fields(result)
    
    for i in range(0, columns):
      print("%s, " % DbtPy.field_name(result, i))
    print("\n\n")
   
    row = DbtPy.fetch_tuple(result) 
    while ( row ):
      final = ", " + row[1] + ", " + row[2] + ", " + row[3] + ", ,";
      row = DbtPy.fetch_tuple(result)

    print(final)
    
    DbtPy.free_result(result)

    DbtPy.exec_immediate(conn, 'DROP TABLE t.t1')
    DbtPy.exec_immediate(conn, 'DROP TABLE t.t2')
    DbtPy.exec_immediate(conn, 'DROP TABLE t.t3')
    DbtPy.exec_immediate(conn, 'DROP TABLE t.t4')

#__END__
#__IDS_EXPECTED__
#TABLE_CAT, TABLE_SCHEM, TABLE_NAME, TABLE_TYPE, REMARKS, 
#
#, t, t3, TABLE, ,



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_011_DeleteRowCount(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_011)

  def run_test_011(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
      
    if conn:
      DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_OFF)
      stmt = DbtPy.exec_immediate(conn, "DELETE FROM animals WHERE weight > 10.0")
      print("Number of affected rows: %d" % DbtPy.num_rows( stmt ))
      DbtPy.rollback(conn)
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Number of affected rows: 3
#__ZOS_EXPECTED__
#Number of affected rows: 3
#__SYSTEMI_EXPECTED__
#Number of affected rows: 3
#__IDS_EXPECTED__
#Number of affected rows: 3




import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):
    def test_spinout_timestamp(self):
        obj = DbtPyTestFunctions()
        obj.assert_expect(self.run_test_spinout_timestamp)

    def run_test_spinout_timestamp(self):
        conn = DbtPy.connect(config.ConnStr, config.user, config.password)

        # Get the server type
        serverinfo = DbtPy.server_info( conn )

        if conn:

            drop = "DROP PROCEDURE PROC_TIMESTAMP"
            try:
                result = DbtPy.exec_immediate(conn,drop)
            except:
                pass

            # Create the SP with timestamp parameters

            
            create = "CREATE PROCEDURE PROC_TIMESTAMP ( INOUT PAR1 DATETIME YEAR TO FRACTION(5), OUT PAR2 DATETIME YEAR TO FRACTION(5)) LET PAR2 = PAR1; END PROCEDURE"
            result = DbtPy.exec_immediate(conn, create)

            # call the SP. Expect PAR2 to contain value passed to PAR1
            par1 = "2017-05-13 22:47:29.82688"
            par2 = ""

            print("Values of bound parameters _before_ CALL:")
            print("  1: %s 2: %s\n" % (par1, par2))

            stmt, par1, par2 = DbtPy.callproc(conn, 'proc_timestamp', (par1, par2))
            if stmt is not None:
                print("Values of bound parameters _after_ CALL:")
                print("  1: %s 2: %s\n" % (par1, par2))

            DbtPy.close(conn)
        else:
            print ("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: 2017-05-13 22:47:29.82688 2: 
#
#Values of bound parameters _after_ CALL:
#  1: 2017-05-13 22:47:29.82688 2: 2017-05-13 22:47:29.82688




# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_100_SelectDeleteInsertFieldCount(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_100)

  def run_test_100(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_OFF)

      stmt = DbtPy.exec_immediate(conn, "SELECT * FROM animals ORDER BY breed")
    
      fields1 = DbtPy.num_fields(stmt)
      
      print("int(%d)" % fields1)
      
      stmt = DbtPy.exec_immediate(conn, "SELECT name, breed FROM animals ORDER BY breed")
      fields2 = DbtPy.num_fields(stmt)
      
      print("int(%d)" % fields2)
      
      stmt = DbtPy.exec_immediate(conn, "DELETE FROM animals")
      fields3 = DbtPy.num_fields(stmt)
      
      print("int(%d)" % fields3)
      
      stmt = DbtPy.exec_immediate(conn, "INSERT INTO animals values (0, 'cat', 'Pook', 3.2)")
      fields4 = DbtPy.num_fields(stmt)
        
      print("int(%d)" % fields4)
      
      stmt = DbtPy.exec_immediate(conn, "SELECT name, breed, 'TEST' FROM animals")
      fields5 = DbtPy.num_fields(stmt)
        
      print("int(%d)" % fields5)

      DbtPy.rollback(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#int(4)
#int(2)
#int(0)
#int(0)
#int(3)
#__ZOS_EXPECTED__
#int(4)
#int(2)
#int(0)
#int(0)
#int(3)
#__SYSTEMI_EXPECTED__
#int(4)
#int(2)
#int(0)
#int(0)
#int(3)
#__IDS_EXPECTED__
#int(4)
#int(2)
#int(0)
#int(0)
#int(3)



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_060_Tables_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_060)

  def run_test_060(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )
    
    create = 'CREATE SCHEMA AUTHORIZATION t'
    try:
      result = DbtPy.exec_immediate(conn, create)
    except:
      pass
    
    create = 'CREATE TABLE t.t1( c1 INTEGER, c2 VARCHAR(40))'
    try:
      result = DbtPy.exec_immediate(conn, create)
    except:
      pass
    
    create = 'CREATE TABLE t.t2( c1 INTEGER, c2 VARCHAR(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t3( c1 INTEGER, c2 VARCHAR(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t4( c1 INTEGER, c2 VARCHAR(40))'
    try:
      result = DbtPy.exec_immediate(conn, create) 
    except:
      pass
    
    if conn:
      result = DbtPy.tables(conn, None, 't')
      i = 0
      row = DbtPy.fetch_both(result)
      while ( row ):
        if (i < 4):
          print("/%s/%s" % (row[1], row[2]))
        i = i + 1
        row = DbtPy.fetch_both(result)

      DbtPy.exec_immediate(conn, 'DROP TABLE t.t1')
      DbtPy.exec_immediate(conn, 'DROP TABLE t.t2')
      DbtPy.exec_immediate(conn, 'DROP TABLE t.t3')
      DbtPy.exec_immediate(conn, 'DROP TABLE t.t4')

      print("done!")
    else:
      print("no connection: #{DbtPy.conn_errormsg}");    

#__END__
#__LUW_EXPECTED__
#/T/T1
#/T/T2
#/T/T3
#/T/T4
#done!
#__ZOS_EXPECTED__
#/T/T1
#/T/T2
#/T/T3
#/T/T4
#done!
#__SYSTEMI_EXPECTED__
#/T/T1
#/T/T2
#/T/T3
#/T/T4
#done!
#__IDS_EXPECTED__
#/t/t1
#/t/t2
#/t/t3
#/t/t4
#done!



#

#

#

import unittest, sys, os
import DbtPy
#need to add this line below to each file to make the connect parameters available to all the test files
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_316_UDT_Param(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_316)

  def run_test_316(self):
    # Make a connection
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)

    # Get the server type
    server = DbtPy.server_info( conn )

    try:
        sql = "drop table rc_create;"
        stmt = DbtPy.exec_immediate(conn, sql)
    except:
        pass

    sql = "DROP ROW TYPE if exists details RESTRICT;"
    DbtPy.exec_immediate(conn, sql)

    sql = "DROP ROW TYPE if exists udt_t1 RESTRICT;"
    DbtPy.exec_immediate(conn, sql)

    sql = " create ROW type details(name varchar(15), addr varchar(15), zip varchar(15) );"
    stmt = DbtPy.exec_immediate(conn, sql)

    sql = " create ROW type udt_t1(name varchar(20), zip int);"
    stmt = DbtPy.exec_immediate(conn, sql)

    sql = "create table rc_create (c1 int, c2 SET(CHAR(10)NOT NULL), c3 MULTISET(int not null), c4 LIST(int not null), c5 details, c6 udt_t1 );"
    stmt = DbtPy.exec_immediate(conn, sql)

    #sql = "INSERT INTO rc_create(c1, c2) values(?, ?);"
    sql = "INSERT INTO rc_create VALUES (?, ?, ?, ?, ?, ?);"
    stmt = DbtPy.prepare(conn, sql)

    c1 = None
    c2 = None
    c3 = None
    c4 = None    
    c5 = None
    c6 = None

    DbtPy.bind_param(stmt, 1, c1, DbtPy.SQL_PARAM_INPUT, DbtPy.SQL_INTEGER)
    DbtPy.bind_param(stmt, 2, c2, DbtPy.SQL_PARAM_INPUT, DbtPy.SQL_CHAR, DbtPy.SQL_INFX_RC_COLLECTION) 
    DbtPy.bind_param(stmt, 3, c3, DbtPy.SQL_PARAM_INPUT, DbtPy.SQL_CHAR, DbtPy.SQL_INFX_RC_COLLECTION)
    DbtPy.bind_param(stmt, 4, c4, DbtPy.SQL_PARAM_INPUT, DbtPy.SQL_CHAR, DbtPy.SQL_INFX_RC_COLLECTION)
    DbtPy.bind_param(stmt, 5, c5, DbtPy.SQL_PARAM_INPUT, DbtPy.SQL_CHAR, DbtPy.SQL_INFX_UDT_FIXED)
    DbtPy.bind_param(stmt, 6, c6, DbtPy.SQL_PARAM_INPUT, DbtPy.SQL_CHAR, DbtPy.SQL_INFX_UDT_VARYING)
    i = 0
    while i < 3:
        i += 1
        c1 = 100+i
        c2 = "SET{'test', 'test1'}"
        c3 = "MULTISET{1,2,3}"
        c4 = "LIST{10, 20}"
        c5 = "ROW('Pune', 'City', '411061')"
        c6 = "ROW('Mumbai', 11111)"
        DbtPy.execute(stmt, (c1, c2, c3, c4, c5, c6));
   

    sql = "SELECT * FROM rc_create"
    stmt = DbtPy.exec_immediate(conn, sql)
    tu = DbtPy.fetch_tuple(stmt)

    print ("UDT Param complete")

#__END__
#__LUW_EXPECTED__
#UDT Param complete
#__ZOS_EXPECTED__
#UDT Param complete
#__SYSTEMI_EXPECTED__
#UDT Param complete
#__IDS_EXPECTED__
#UDT Param complete



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_147_PrepareWithWrongType(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_147)

  def run_test_147(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      DbtPy.autocommit(conn, DbtPy.SQL_AUTOCOMMIT_OFF)

      stmt = DbtPy.prepare(conn, "INSERT INTO animals (id, breed, name) VALUES (?, ?, ?)")
    
      id = "\"999\""
      breed = None
      name = 'PythonDS'
      try:
          DbtPy.bind_param(stmt, 1, id)
          DbtPy.bind_param(stmt, 2, breed)
          DbtPy.bind_param(stmt, 3, name)
       
          error = DbtPy.execute(stmt)
          print("Should not make it this far")
      except:
          excp = sys.exc_info()
          # slot 1 contains error message
          print(excp[1])
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#Statement Execute Failed: [GBasedbt][GBase ODBC Driver]Invalid character value for cast specification. SQLCODE=-11106



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_008_ColumnInfo(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_008)

  def run_test_008(self):
    op = {DbtPy.ATTR_CASE: DbtPy.CASE_NATURAL}
    conn = DbtPy.connect(config.ConnStr, config.user, config.password, op)
    server = DbtPy.server_info( conn )
    result = DbtPy.columns(conn,None,None,"employee")
    row = DbtPy.fetch_both(result)
    value1 = None
    value2 = None
    value3 = None
    value4 = None
    if ('TABLE_NAME' in row):
      value1 = row['TABLE_NAME']
    if ('COLUMN_NAME' in row):
      value2 = row['COLUMN_NAME']
    if ('table_name' in row):
      value3 = row['table_name']
    if ('column_name' in row):
      value4 = row['column_name']
    print(value1)
    print(value2)
    print(value3)
    print(value4)

    op = {DbtPy.ATTR_CASE: DbtPy.CASE_UPPER}
    DbtPy.set_option(conn, op, 1)
    result = DbtPy.columns(conn,None,None,"employee")
    row = DbtPy.fetch_both(result)
    value1 = None
    value2 = None
    value3 = None
    value4 = None
    if ('TABLE_NAME' in row):
      value1 = row['TABLE_NAME']
    if ('COLUMN_NAME' in row):
      value2 = row['COLUMN_NAME']
    if ('table_name' in row):
      value3 = row['table_name']
    if ('column_name' in row):
      value4 = row['column_name']
    print(value1)
    print(value2)
    print(value3)
    print(value4)
    
    op = {DbtPy.ATTR_CASE: DbtPy.CASE_LOWER}
    DbtPy.set_option(conn, op, 1)
    result = DbtPy.columns(conn,None,None,"employee")
    row = DbtPy.fetch_both(result)
    value1 = None
    value2 = None
    value3 = None
    value4 = None
    if ('TABLE_NAME' in row):
      value1 = row['TABLE_NAME']
    if ('COLUMN_NAME' in row):
      value2 = row['COLUMN_NAME']
    if ('table_name' in row):
      value3 = row['table_name']
    if ('column_name' in row):
      value4 = row['column_name']
    print(value1)
    print(value2)
    print(value3)
    print(value4)

#__END__
#__IDS_EXPECTED__
#employee
#empno
#None
#None
#employee
#empno
#None
#None
#None
#None
#employee
#empno



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_211_FieldDisplaySize_02(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_211)

  def run_test_211(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    result = DbtPy.exec_immediate(conn, "select * from sales")
    
    i = 1
    
    while (i <= DbtPy.num_fields(result)):
      #printf("%d size %d\n",i, DbtPy.field_display_size(result,i) || 0)
      print("%d size %d" % (i, DbtPy.field_display_size(result,i) or 0))
      i += 1
    
    DbtPy.close(conn)

#__END__
#__LUW_EXPECTED__
#1 size 15
#2 size 15
#3 size 11
#4 size 0
#__ZOS_EXPECTED__
#1 size 15
#2 size 15
#3 size 11
#4 size 0
#__SYSTEMI_EXPECTED__
#1 size 15
#2 size 15
#3 size 11
#4 size 0
#__IDS_EXPECTED__
#1 size 15
#2 size 15
#3 size 11
#4 size 0



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_6755_ExtraNULLChar_ResultCLOBCol(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_6755)

  def run_test_6755(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    server = DbtPy.server_info( conn )
    
    if conn:
      drop = 'DROP TABLE table_6755'
      result = ''
      try:
        result = DbtPy.exec_immediate(conn, drop)
      except:
        pass

      if (server.DBMS_NAME[0:3] == 'Inf'):
        create = 'CREATE TABLE table_6755 (col1 VARCHAR(20), col2 CLOB)'
        insert = "INSERT INTO table_6755 VALUES ('database', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\test_6755.txt','client'))"
      else:
        create = 'CREATE TABLE table_6755 (col1 VARCHAR(20), col2 CLOB(20))'
        insert = "INSERT INTO table_6755 VALUES ('database', FILETOCLOB('C:\\work\\DbtPy\\DbtPy\\tests\\data\\test_6755.txt','client'))"
      result = DbtPy.exec_immediate(conn, create)
      result = DbtPy.exec_immediate(conn, insert)
      statement = "SELECT col1, col2 FROM table_6755"
    
      result = DbtPy.prepare(conn, statement)
      DbtPy.execute(result)
    
      row = DbtPy.fetch_tuple(result)
      while ( row ):
        #printf("\"%s\" from VARCHAR is %d bytes long, \"%s\" from CLOB is %d bytes long.\n",
        #    row[0], row[0].length,
        #    row[1], row[1].length)
        print("\"%s\" from VARCHAR is %d bytes long, \"%s\" from CLOB is %d bytes long." % (row[0], len(row[0]), row[1], len(row[1])))
        row = DbtPy.fetch_tuple(result)
      
      DbtPy.close(conn)
    else:
      print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#"database" from VARCHAR is 8 bytes long, "database" from CLOB is 8 bytes long.
#__ZOS_EXPECTED__
#"database" from VARCHAR is 8 bytes long, "database" from CLOB is 8 bytes long.
#__SYSTEMI_EXPECTED__
#"database" from VARCHAR is 8 bytes long, "database" from CLOB is 8 bytes long.
#__IDS_EXPECTED__
#"database" from VARCHAR is 8 bytes long, "database" from CLOB is 8 bytes long.



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_032_ResultIndexName(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_032)

  def run_test_032(self):
      conn = DbtPy.connect(config.ConnStr, config.user, config.password)
      server = DbtPy.server_info( conn )

      if conn:
        stmt = DbtPy.exec_immediate(conn, "SELECT id, breed, name, weight FROM animals WHERE id = 6")
        
        while (DbtPy.fetch_row(stmt)):
          id = DbtPy.result(stmt, "id")
          breed = DbtPy.result(stmt, "breed")
          name = DbtPy.result(stmt, "name")
          weight = DbtPy.result(stmt, "weight")
          print("int(%d)" % id)
          print("string(%d) \"%s\"" % (len(breed), breed))
          print("string(%d) \"%s\"" % (len(name), name))
          print("string(%d) \"%s\"" % (len(str(weight)), weight))
        DbtPy.close(conn)
      else:
        print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#int(6)
#string(5) "llama"
#string(16) "Sweater         "
#string(6) "150.00"
#__ZOS_EXPECTED__
#int(6)
#string(5) "llama"
#string(16) "Sweater         "
#string(6) "150.00"
#__SYSTEMI_EXPECTED__
#int(6)
#string(5) "llama"
#string(16) "Sweater         "
#string(6) "150.00"
#__IDS_EXPECTED__
#int(6)
#string(5) "llama"
#string(16) "Sweater         "
#string(6) "150.00"



# 

#

#

import unittest, sys
import DbtPy
import config
from testfunctions import DbtPyTestFunctions

class DbtPyTestCase(unittest.TestCase):

  def test_148_CallSPDiffBindPattern_01(self):
    obj = DbtPyTestFunctions()
    obj.assert_expect(self.run_test_148)

  def run_test_148(self):
    conn = DbtPy.connect(config.ConnStr, config.user, config.password)
    
    if conn:
      ##### Set up #####
      serverinfo = DbtPy.server_info( conn )
      server = serverinfo.DBMS_NAME[0:3]
      try:
          sql = "DROP TABLE sptb"
          DbtPy.exec_immediate(conn, sql)
      except:
          pass
      
      try:
          sql = "DROP PROCEDURE sp"
          DbtPy.exec_immediate(conn, sql)
      except:
          pass
      
      sql = "CREATE TABLE sptb (c1 INTEGER, c2 FLOAT, c3 VARCHAR(10), c4 INT8, c5 VARCHAR(20))"
      
      DbtPy.exec_immediate(conn, sql)
      
      sql = "INSERT INTO sptb (c1, c2, c3, c4, c5) VALUES (1, 5.01, 'varchar', 3271982, 'varchar data')"
      DbtPy.exec_immediate(conn, sql)
      
      sql = """CREATE PROCEDURE sp(OUT out1 INTEGER, OUT out2 FLOAT, OUT out3 VARCHAR(10), OUT out4 INT8, OUT out5 VARCHAR(20));
                 SELECT c1, c2, c3, c4, c5 INTO out1, out2, out3, out4, out5 FROM sptb; END PROCEDURE;"""
      DbtPy.exec_immediate(conn, sql)
      #############################

      ##### Run the test #####

      out1 = 0
      out2 = 0.00
      out3 = ""
      out4 = 0
      out5 = ""

      stmt, out1, out2, out3, out4, out5 = DbtPy.callproc(conn, 'sp', (out1, out2, out3, out4, out5))

      print("out 1:")
      print(out1)
      print("out 2:")
      print(out2)
      print("out 3:")
      print(out3)
      print("out 4:")
      print(out4)
      print("out 5:")
      print(out5)
      #############################
    else:
      print("Connection failed.")

#__END__
#__IDS_EXPECTED__
#out 1:
#1
#out 2:
#5.01
#out 3:
#varchar
#out 4:
#3271982
#out 5:
#varchar data
